﻿# Adobe Reader XI MUI
# 2017 foo.li systeme + software
# http://www.adobe.com/support/downloads/product.jsp?platform=windows&product=10

$packageName    = 'foo-adobe-reader'
$packageSearch  = 'Adobe Reader XI*'
$mainversion    = '11.0.00'
$patchversion   = '11.0.23'
$installerType  = 'MSI'
#ftp is slow as hell..
$mainurl        = 'http://ardownload.adobe.com/pub/adobe/reader/win/11.x/11.0.00/misc/AdbeRdr11000_mui_Std.zip'
$patchurl       = 'http://ardownload.adobe.com/pub/adobe/reader/win/11.x/11.0.23/misc/AdbeRdrUpd11023_MUI.msp'
#$silentArgs     = '/qn /norestart ALLUSERS=1 EULA_ACCEPT=YES'
$doNotNeed      = 'updater.api'
# msi and update/patch related settings
$installerPath  = $(Split-Path -parent $MyInvocation.MyCommand.Definition)
$mainZipLoc     = Join-Path $installerPath 'reader.zip'
$mainPath       = Join-Path $installerPath 'AcroRead.msi'
$SilentArgs     = '/i "' + $mainPath + '" /qn /norestart ALLUSERS=1 EULA_ACCEPT=YES' 
$patchPath      = Join-Path $installerPath 'AdbeRdrUpd11023_MUI.msp'
$mspArgs        = '/p "' + $patchPath + '" /quiet'
$validExitCodes = @(0,3010)
$checksumMain   = 'B056028E10B887AB7541F8C11655417FDBC5F68A'
$checksumType   = 'sha1'
$checksumMinor  = 'F84B11B3DCF6B03918C4B9DE15EA49CE9D0D72A4' #11.0.23

if ($env:PROCESSOR_ARCHITECTURE -eq 'AMD64') {
    $progdir    = ${env:ProgramFiles(x86)} + '\Adobe\Reader 11.0'
} else {
    $progdir    = $env:ProgramFiles + '\Adobe\Reader 11.0'
}
 
try {
    $app = Get-ItemProperty -Path @('HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
                                    'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*') `
            -ErrorAction:SilentlyContinue | Where-Object { $_.DisplayName -like $packageSearch }

    if ($app -and ([version]$app.DisplayVersion -ge [version]$mainversion)) {
        Write-Output $(
        'Adobe Reader XI ('+$mainversion+') is already installed. ' +
        'No need to install again.'
        )
    } else {
        Write-Host 'downloading main installer files...this may take a moment...'
        #(New-Object Net.WebClient).DownloadFile($mainurl,$env:Temp +'\reader11.zip'); `
        #    (New-object -com shell.application).namespace($env:Temp).CopyHere((new-object -com shell.application).namespace($env:Temp +'\reader11.zip').Items(),16)
        #$url = $env:Temp +'\AcroRead.msi'
        #Install-ChocolateyPackage $packageName $fileType $silentArgs $url
        Get-ChocolateyWebFile $packageName $mainZipLoc $mainurl `
                            -checksum $checksumMain -checksumtype $checksumType
        Write-Host 'extracting zip file...'
        (New-object -com shell.application).namespace($installerPath).CopyHere((new-object -com shell.application).namespace($mainZipLoc).Items(),16)
        Write-Host 'installing main version of Acrobat Reader XI...'
        Start-ChocolateyProcessAsAdmin $silentArgs 'msiexec' -validExitCodes $validExitCodes
    }
    $patch = Get-ItemProperty -Path @('HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
                                    'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*') `
            -ErrorAction:SilentlyContinue | Where-Object { $_.DisplayName -like $packageSearch }

    if ($app -and ([version]$app.DisplayVersion -ge [version]$patchversion)) {
        Write-Output $(
        'Adobe Reader XI ('+$patchversion+') is already installed. ' +
        'No need to install again.'
        )
    } else {
        Write-Host 'need to install patch...' $patchversion
        Get-ChocolateyWebFile $packageName $patchPath $patchurl `
                            -checksum $checksumMinor -checksumtype $checksumType
        Start-ChocolateyProcessAsAdmin $mspArgs 'msiexec' -validExitCodes $validExitCodes
    }
    Write-Host 'housekeeping...'
    Remove-Item -Path $mainZipLoc -ErrorAction SilentlyContinue
    Remove-Item -Path $patchPath -ErrorAction SilentlyContinue
    Remove-Item -Path "$installerPath\Transforms" -Force -Recurse -ErrorAction SilentlyContinue
    Remove-Item -Path "$installerPath\AcroRead.msi" -Force -ErrorAction SilentlyContinue
    Remove-Item -Path "$installerPath\Setup.exe" -Force -ErrorAction SilentlyContinue
    Remove-Item -Path "$installerPath\Data1.cat" -Force -ErrorAction SilentlyContinue
    Remove-Item -Path "${env:PUBLIC}\Desktop\Adobe Reader XI.lnk" -ErrorAction SilentlyContinue
    foreach ($file in $doNotNeed) {
        Remove-Item (Join-Path $progdir "\Reader\plug_ins\$file") -Force -ErrorAction SilentlyContinue
    }
} catch {
    throw $_.Exception
}
